@@ -1,4 +1,4 @@
-/* $Id: unshield.c 2995 2007-08-05 07:47:46Z twogood $ */
+/* $Id: unshield.c 3783 2009-06-18 05:11:31Z mark_ellis $ */
 #ifdef __linux__
 #define _BSD_SOURCE 1
 #define _POSIX_C_SOURCE 2
@@ -316,7 +316,7 @@ static bool extract_file(Unshield* unshield, const char* prefix, int index)
   snprintf(filename, sizeof(filename), "%s%s", 
       dirname, unshield_file_name(unshield, index));
 
-  for (p = filename; *p != '\0'; p++)
+  for (p = filename + strlen(dirname); *p != '\0'; p++)
   {
     if (!isprint(*p))
       *p = '_';
